@@ -106,7 +106,7 @@ class BaseNode:
     3. ``set_attrs(attrs: dict)``: Set node attribute name(s) and value(s)
     4. ``copy()``: Deep copy BaseNode
 
-    ------------
+    ----
 
     """
 
@@ -512,6 +512,12 @@ class BaseNode:
         obj.__dict__.update(self.__dict__)
         return obj
 
+    def __repr__(self):
+        class_name = self.__class__.__name__
+        node_dict = self.describe(exclude_prefix="_")
+        node_description = ", ".join([f"{k}={v}" for k, v in node_dict])
+        return f"{class_name}({node_description})"
+
     def __rshift__(self, other):
         """Set children using >> bitshift operator for self >> other
 
