@@ -1,4 +1,4 @@
-from typing import Callable, Iterable, List
+from typing import Callable, Iterable, List, Tuple
 
 __all__ = [
     "preorder_iter",
@@ -29,13 +29,13 @@ def preorder_iter(
     >>> root = list_to_tree(path_list)
     >>> print_tree(root)
     a
-    |-- b
-    |   |-- d
-    |   `-- e
-    |       |-- g
-    |       `-- h
-    `-- c
-        `-- f
+    ├── b
+    │   ├── d
+    │   └── e
+    │       ├── g
+    │       └── h
+    └── c
+        └── f
 
     >>> [node.node_name for node in preorder_iter(root)]
     ['a', 'b', 'd', 'e', 'g', 'h', 'c', 'f']
@@ -90,13 +90,13 @@ def postorder_iter(
     >>> root = list_to_tree(path_list)
     >>> print_tree(root)
     a
-    |-- b
-    |   |-- d
-    |   `-- e
-    |       |-- g
-    |       `-- h
-    `-- c
-        `-- f
+    ├── b
+    │   ├── d
+    │   └── e
+    │       ├── g
+    │       └── h
+    └── c
+        └── f
 
     >>> [node.node_name for node in postorder_iter(root)]
     ['d', 'g', 'h', 'e', 'b', 'f', 'c', 'a']
@@ -142,13 +142,13 @@ def levelorder_iter(
     >>> root = list_to_tree(path_list)
     >>> print_tree(root)
     a
-    |-- b
-    |   |-- d
-    |   `-- e
-    |       |-- g
-    |       `-- h
-    `-- c
-        `-- f
+    ├── b
+    │   ├── d
+    │   └── e
+    │       ├── g
+    │       └── h
+    └── c
+        └── f
 
     >>> [node.node_name for node in levelorder_iter(root)]
     ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h']
@@ -197,13 +197,13 @@ def levelordergroup_iter(
     >>> root = list_to_tree(path_list)
     >>> print_tree(root)
     a
-    |-- b
-    |   |-- d
-    |   `-- e
-    |       |-- g
-    |       `-- h
-    `-- c
-        `-- f
+    ├── b
+    │   ├── d
+    │   └── e
+    │       ├── g
+    │       └── h
+    └── c
+        └── f
 
     >>> [[node.node_name for node in group] for group in levelordergroup_iter(root)]
     [['a'], ['b', 'c'], ['d', 'e', 'f'], ['g', 'h']]
@@ -239,9 +239,10 @@ def levelordergroup_iter(
         )
 
 
-def dag_iterator(dag):
+def dag_iterator(dag) -> Iterable[Tuple]:
     """Iterate through all nodes of a Directed Acyclic Graph (DAG).
     Note that node names must be unique.
+    Note that DAG must at least have two nodes to be shown on graph.
 
     1. Visit the current node.
     2. Recursively traverse the current node's parents.
@@ -260,7 +261,7 @@ def dag_iterator(dag):
         dag (DAGNode): input dag
 
     Returns:
-        (List[Tuple[DAGNode, DAGNode]])
+        (Iterable[Tuple[DAGNode, DAGNode]])
     """
     visited_nodes = set()
 
