@@ -74,6 +74,14 @@ def tree_node():
     return a
 
 
+@pytest.fixture
+def tree_node_plot():
+    z = Node("z")
+    y = Node("y")
+    y.parent = z
+    return z
+
+
 @pytest.fixture
 def tree_node_duplicate_names():
     """
@@ -225,6 +233,14 @@ def dag_node():
     return a
 
 
+@pytest.fixture
+def dag_node_plot():
+    z = DAGNode("z")
+    y = DAGNode("y")
+    y.parents = [z]
+    return z
+
+
 @pytest.fixture
 def dag_node_child():
     a = DAGNode("a", age=90)
